import greenfoot.*;

/** for balloons */
public class Balloon extends QActor
{
    String[] names = { "g1", "a2", "b2", "c2", "d2", "e2", "f2" }; // sound file names
    String[] words = { "We", "wish", "you", "a", "merry", "Christmas", "and", "happy", "new", "year" }; // words used in song
    int colorIndex = Greenfoot.getRandomNumber(3); // random color (blue, red, or yellow)
    int id, val; // for tone and word values
    int swing; // movement control value
    
    public Balloon(int size, int value)
    {
        id = size; // tone value (and inverse size factor)
        val = value; // word value
        // the image
        setImage("balloon"+(1+colorIndex)+".png");
        getImage().scale(getImage().getWidth()*20/(2*id), getImage().getHeight()*20/(2*id));
        // random initial amount of sway
        swing = Greenfoot.getRandomNumber(360);
        sway(swing);
    }
    
    public void act()
    {
        sway(++swing); // sway adjustment
        // rise (with respect to amount of sway
        turn(-90*QVAL);
        move(QVAL*4/5);
        turn(90*QVAL);
        // pop, sound and show word (if any) 
        if (getY() <= 45)
        {
            Greenfoot.playSound(names[id-5]+".wav");
            if (val != -1) getWorld().addObject(new Tape(), getX(), getY());
            getWorld().removeObject(this);
        }
    }
    
    private void sway(int n)
    { // adjusts sway
        setQRotation((int)(Math.sin(n*Math.PI/180)*30*QVAL));
    }
    
    /** for words */
    private class Tape extends Actor
    {
        public Tape()
        {
            // the image
            Color color = (new Color[] { Color.RED, Color.BLUE, Color.YELLOW })[colorIndex];
            GreenfootImage txt = new GreenfootImage(words[val], 28, Color.BLACK, Color.WHITE, color);
            GreenfootImage img = new GreenfootImage(txt.getWidth()+10, txt.getHeight()+10);
            img.setColor(color);
            img.fill();
            img.setColor(Color.BLACK);
            img.drawRect(0, 0, img.getWidth()-1, img.getHeight()-1);
            img.drawImage(txt, 5, 5);
            setImage(img);
        }
        
        public void act()
        {
            // fade and remove
            int t = getImage().getTransparency();
            if (t == 0) getWorld().removeObject(this);
            else getImage().setTransparency(t-5);
        }
    }
}